@@ -232,13 +232,13 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
     for sec_after in sec_after_list:
         col = int(sec_after // 30*60 - 1)
-        df = pd.concat([df, mims_summary_after_df[col].rename("mims_summary_" + str(sec_after // 60) + "min_after")],
+        df = pd.concat([df, mims_summary_after_df[col].rename("mims_summary_" + str(sec_after // 30*60) + "min_after")],
                        axis=1)
         df = pd.concat(
-            [df, window_readings_after_df[col].rename("window_num_readings_" + str(sec_after // 60) + "min_after")],
+            [df, window_readings_after_df[col].rename("window_num_readings_" + str(sec_after // 30*60) + "min_after")],
             axis=1)
         df = pd.concat(
-            [df, window_start_time_after_df[col].rename("window_start_time_" + str(sec_after // 60) + "min_after")],
+            [df, window_start_time_after_df[col].rename("window_start_time_" + str(sec_after // 30*60) + "min_after")],
             axis=1)
 
     return df
